@@ -3,7 +3,7 @@
            ncp=0,
            log.p=FALSE,
            xlim.in=c(0, qchisq.intermediate(p=1-.01, df=df, ncp=ncp, log.p=log.p)),
-           ylim.in=range(c(0, 1.1*dchisq.intermediate(x=seq(min(0,df-2),df+2,.01), df=df, ncp=ncp, log=log.p))),
+           ylim.in=range(c(0, 1.1*dchisq.intermediate(x=seq(max(0.5,df-2),df+2,.01), df=df, ncp=ncp, log=log.p))),
            main.in=main.calc,
            ...) {
     main.calc <- parse(text=
